# BEGIN COPYRIGHT
# *************************************************************************
# Licensed Materials - Property of IBM 
# 5724-L01, 5655-N53, 5724-I82, 5655-R15
# (C) Copyright IBM Corporation 2007, 2008, 2009. All rights reserved. 
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
# *************************************************************************
# END COPYRIGHT

# import related classes
import sys;
from java.lang import *;
import java.io.File as File;
import re;
import shutil;
import os;
import os.path;

#------------------------------------------------------------------------------
# get the property value by the the property name; If property not available, return ''
#------------------------------------------------------------------------------
def getPropertyValue(propertyName):
	propertyValue = java.lang.System.getProperty(propertyName);
	if(propertyValue == None):
		return '';
	return propertyValue;
#endDef

#-----------------------------------------------------------------
# Logs messages
#-----------------------------------------------------------------
def trace(message):
    print message;
#endDef

#--------------------------------------------------------------
# Helper Class to normalize the string for comparison
#--------------------------------------------------------------
def wsadminToList(inStr):
	outList=[]
	if (len(inStr)>0 and inStr[0]=='[' and inStr[-1]==']'):
		tmpList = inStr[1:-1].split() #splits space-separated lists,
	else:
		tmpList = inStr.split("\n")   #splits for Windows or Linux
	for item in tmpList:
		item = item.rstrip();         #removes any Windows "\r"
		if (len(item)>0):
			outList.append(item)
	return outList;
#endDef

#-----------------------------------------------------------------
# Path utilities: 
# exists: return 1;
# not exist: return 0;
#-----------------------------------------------------------------
def existsPath(pathName):
	newPath=File(pathName);
	return newPath.exists();
#endDef
 
def normalizePath(pathName):
	newPath=File(pathName);
	return newPath.getAbsolutePath();
#endDef

#--------------------------------------------------------------
# Get Backup Folder for Migrtaing WPS Profile
#--------------------------------------------------------------
def getBackupDir():
	return getPropertyValue('wbi.upgrade.backup.dir');
	#return "E:\\backup601";
#endDef

#--------------------------------------------------------------
# Get Migrating WPS ProfileName
#--------------------------------------------------------------
def getPreviousProfileName():
	return getPropertyValue('wbi.upgrade.previous.profileName');
	#return "ProcSrv01";
#endDef

#--------------------------------------------------------------
# Get a value of WPSHOME.that is migrated to.
#--------------------------------------------------------------
def getWASHome():
	return getPropertyValue('was.install.root');
#endDef

#------------------------------------------------------------------------------
# get the was.repository.root
#------------------------------------------------------------------------------
def getRepository():
	return getPropertyValue('was.repository.root');
#endDef
	
#------------------------------------------------------------------------------
# get the profilePath.
#------------------------------------------------------------------------------
def getProfilePath():
	repositoryPath=getRepository();
	profilePath=File(repositoryPath).getParent();
	return profilePath;
#endDef

#------------------------------------------------------------------------------
# get the cell name
#------------------------------------------------------------------------------
def getCellName():
	return getPropertyValue('local.cell');
#endDef

#------------------------------------------------------------------------------
# get the node name
#------------------------------------------------------------------------------
def getNodeName():
	return getPropertyValue('local.node');
#endDef

#------------------------------------------------------------------------------
# get the node type: managed,unmanaged,
#------------------------------------------------------------------------------
def getNodeType():
	return getPropertyValue('wbi.upgrade.node.type');
#endDef


#------------------------------------------------------------------------------
# get the scope Id according to cellname ,nodename, servername
#------------------------------------------------------------------------------
def getScopeId(cellName,nodeName,serverName):
	trace("****************getScopeId() start****************");
	scopeId="";
	if (cellName ==''):
		scopeId='';
	elif (nodeName ==''):
		scopeId=AdminConfig.getid('/Cell:' + cellName);
	elif (serverName == ''):
		scopeId=AdminConfig.getid('/Cell:' + cellName + '/Node:' + nodeName);
	else:
		scopeId=AdminConfig.getid('/Cell:' + cellName + '/Node:' +nodeName + '/Server:' + serverName);
	#endIf
	trace("****************getScopeId() end****************");
	return scopeId;
#endDef

def getExactScopeId(Id,cellName,nodeName,serverName):
	# get exact variable which is only located in  cell ,node or server level.
	filteredId="";
	if(cellName == ""):
		filteredId="";
	elif(nodeName == ""):
		filteredId=locateId(Id,"cell");
	elif(serverName == ""):
		filteredId=locateId(Id,"node");
	else:
		filteredId=locateId(Id,"server");
	#endIf
	
	return filteredId;
#endDef

#---------------------------------------------------------------------------------------------------------------
# locate resource in cell , node or server level.
#---------------------------------------------------------------------------------------------------------------
def locateId(element,scopeLevel):
	if ( scopeLevel == "cell" ):
		#cell level
		if ( re.search(".*(cells).*",element) != None and
			re.search(".*(nodes).*",element) == None and
			re.search(".*(clusters).*",element) == None and
			re.search(".*(servers).*",element) == None):
			return element;
		else:
			return "";
		#endIf
	elif ( scopeLevel == "node" ):
		#node level
		if ( re.search(".*(cells).*",element) != None and
			re.search(".*(nodes).*",element) != None and
			re.search(".*(clusters).*",element) == None and
			re.search(".*(servers).*",element) == None):
			return element;
		else:
			return "";
		#endIf
	elif ( scopeLevel == "server" ):
		#node level
		if ( re.search(".*(cells).*",element) != None and
			re.search(".*(clusters).*",element) == None and
			re.search(".*(nodes).*",element) != None and
			re.search(".*(servers).*",element) != None):
			return element;
		else:
			return "";
		#endIf
	else:
		return "";
	#endIf
#endDef

#-----------------------------------------------------------------
# Returns the value of the environment variable
#-----------------------------------------------------------------
def getVariableValue (variableName,cellName,nodeName,serverName):
	trace("****************getVariableValue() start****************");
	variables=getVariableMapIds (variableName,cellName,nodeName,serverName);
	if(len(variables) > 0):
		variableValue = AdminConfig.showAttribute(variables[0], "value");
		trace ("The value of " + variableName + " is '" + str(variableValue) + "'");
		trace("****************getVariableValue() end****************");
		return variableValue;
	else:
		trace("****************getVariableValue() end****************");
		return "";
	#endIf
#endDef

#-----------------------------------------------------------------
# Returns  id of the environment variable
#-----------------------------------------------------------------
def getVariableMapIds (variableName,cellName,nodeName,serverName):
	global AdminConfig;
	
	variableMapIds=[];
	trace("****************getVariableMapIds() start****************");
	trace ("Scope: ##cellName:"+cellName+" ##nodeName:"+nodeName+" ##serverName:"+serverName);
	trace ("To parse environment variable '" + variableName + "'");
	
	scopeId=getScopeId(cellName,nodeName,serverName);
	variableLists = wsadminToList(AdminConfig.list("VariableMap",scopeId));
	for eachList in variableLists :
		entries = wsadminToList(AdminConfig.list("VariableSubstitutionEntry", eachList));
		for entry in entries:
			# get exact variable which is only located in  cell ,node or server level.
			entry=getExactScopeId(entry,cellName,nodeName,serverName);
			
			if ( entry!="" and AdminConfig.showAttribute(entry, "symbolicName") == variableName):
				variableValue = AdminConfig.showAttribute(entry, "value");
				trace ("The value of " + variableName + " is '" + str(variableValue) + "'");
				trace ("VariableMapId:"+entry);
				variableMapIds.append(entry);
			#endIf
		#endFor
	#endFor
	trace("****************getVariableMapIds() end****************");
	return variableMapIds;
#endDef
	
#---------------------------------------------------------------------------------------------------------------------------------------------------------
#  set a WebSphere environment variable
#---------------------------------------------------------------------------------------------------------------------------------------------------------
def setVariableValue(variableName,variableValue,cellName,nodeName,serverName):
	trace("****************setVariableValue() start****************");
	try:
		global AdminConfig;
		trace ("Scope: ##cellName:"+cellName+" ##nodeName:"+nodeName+" ##serverName:"+serverName);
		trace ("##name:"+variableName+" ##value:"+str(variableValue));
		
		varMapIds = getVariableMapIds (variableName,cellName,nodeName,serverName);
		if(len(varMapIds)!=0):
			for varMap in varMapIds:
				trace ("##varMapId being modified:"+varMap);
				attribute=[['value', variableValue]];
				AdminConfig.modify(varMap, attribute);
				AdminConfig.save();
			#endFor
			trace("****************setVariableValue() end****************");
			return 1;
		#endIf
		trace("****************setVariableValue() end****************");
		return 0;
	except:
		print "Error during setVariableValue():", sys.exc_info();
		trace("****************setVariableValue() end****************");
		return 0;
	#endTry
#endDef

#--------------------------------------------------------------------------------------------------------------------------------------------
# get a value of  WPSHOME.that is migrated.
# main logic:
# get MigratedWASHOME from ${backupDir}/websphere_backup/properties/profileRegistry.xml file.
#---------------------------------------------------------------------------------------------------------------------------------------------
def getMigratedWASHome():
	trace("****************getMigratedWASHome() start****************");
	backupDir=getBackupDir();
	trace("wbi migration backup dir:"+backupDir);
	profileRegistryFile=backupDir+File.separator+"websphere_backup"+File.separator+"properties"+File.separator+"profileRegistry.xml";
	sourceFile=open(profileRegistryFile,"r");
	srclines=sourceFile.readlines();
	sourceFile.close();
	for srcline in srclines :
		# trace(srcline);
		foundString='template="';
		foundStringLen=len(foundString);
		startIndex=srcline.find(foundString);
		if(startIndex!=-1):
			endIndex=srcline.find('">',startIndex+foundStringLen);
			templatePath=srcline[startIndex+foundStringLen:endIndex];
			trace("templatePath: "+templatePath);
			foundTemplatePathString="profileTemplates";
			templatePathStartIndex=templatePath.find(foundTemplatePathString);
			wasHome=templatePath[0:templatePathStartIndex - 1];
			trace("WASHOME: "+wasHome);
			break;
		#endIf
	#endFor
	trace("****************getMigratedWASHome() end****************");
	return wasHome;
#endDef

#---------------------------------------------------------------------------
# convert 60x variable to 61 variable:
# for example:   
# c:/wps601/profiles/proc1 ---> c:/wps61/profiles/proc1
#----------------------------------------------------------------------------
def convertPathFrom60xTo61(variable60x):
	trace("****************convertPathFrom60xTo61() start****************");
	
	# the location of 60x was root home 
	migratedWPSHome=normalizePath(getMigratedWASHome());
	migratedWPSHome=migratedWPSHome.replace('\\',"/");
	trace("migratedWPSHome:"+migratedWPSHome);
	
	#the location of 61 was root home
	presentWPSHome=normalizePath(getWASHome());
	presentWPSHome=presentWPSHome.replace('\\',"/");
	trace("presentWPSHome:"+presentWPSHome);
	
	#convert a variable of 60x to  a new variable of 61.
	variable61="";
	if (variable60x.find(migratedWPSHome)!=-1):
		foundStringLenMigratedWPSHome=len(migratedWPSHome); 
		str = variable60x[0:foundStringLenMigratedWPSHome+ 1]
		if ( (migratedWPSHome+"/"  == str) or (migratedWPSHome+"\\"  == str)  ):
			variable61=variable60x.replace(migratedWPSHome,presentWPSHome);
			trace("original value:"+variable60x);
			trace("replaced value:"+variable61);
		#endIf
	else:
		variable61=variable60x;
	#endIf
	
	trace("****************convertPathFrom60xTo61() end****************");
	return variable61;
#endDef

#-----------------------------------------------------------------
# Apply for 61x  and Above Migration
# copy some required properties from a temp/commondb.property file  into a new commondb.property file 
#-----------------------------------------------------------------  
def copyFileFrom61x(source,dest,profilePath):
	trace("****************copyFileFrom61x() start****************");
	if( existsPath(source)==0 ):
		trace("migration failed because it cannot find the file "+source);
		return 0;
	#endIf

	sourceFile=open(source,"r");
	destFile=open(dest,"w");
	srclines=sourceFile.readlines();
	sourceFile.close();
	
	dbTypeValue="";
	dbNameValue="";
	dbUserIdValue="";
	dbSchemaNameValue="";
	
	
	for srcline in srclines :
		words=srcline.split("=");
		
		keys=["templatePath","cellName","nodeName","hostName","federateLater","dmgrHost","dmgrPort","portsFile"];
		keys.append("dbName");
		keys.append("dbType");
		keys.append("dbDriverType");
		keys.append("dbLocation");
		keys.append("dbUserId");
		keys.append("dbServerPort");
		keys.append("dbServerName");
		keys.append("dbHostName");
		keys.append("dbInstance");
		keys.append("dbJDBCClasspath");
		keys.append("dbCreateNew");
		keys.append("dbSchemaName");
		keys.append("dbStorageGroup");
		keys.append("dbConnectionLocation");
		keys.append("configureAppScheduler");
		keys.append("appSchedulerServer");
		keys.append("dbCommonForME");
		keys.append("fileStoreForME");
		keys.append("dbDelayConfig");
		keys.append("dbAlreadyConfigured");
		keys.append("dbOutputScriptDir");
		keys.append("dbCommonUserId");
		
		
		#print keys;
		if (len(words)==2 and words[0] in keys): 
			# specify some keys which are converted from 60x env to 61 env.
			needPathConversionKeys=["templatePath","dbLocation","dbJDBCClasspath","dbOutputScriptDir"];
			
			# different handlers against different keys.
			if ( words[0]=='dbType' ) :
				if (words[1].upper()=='CLOUDSCAPE\n'):
					key=words[0];
					value='DERBY_EMBEDDED\n';
				elif ( words[1].upper()=='ORACLE10G\n' or words[1].upper()=='ORACLE9I\n' ):
					key=words[0];
					value='ORACLE\n';
				elif ( words[1].upper()=='MSSQLSERVER_EMBEDDED\n'):
					key=words[0];
					value='MSSQLSERVER_MICROSOFT\n';
				else:
					key=words[0];
					value=words[1];
				#endIf
				dbTypeValue=value.split("\n")[0];
			elif ( words[0]=="dbName" ):
				key=words[0];
				value=words[1];
				dbNameValue=words[1].split("\n")[0];
			elif ( words[0]=="dbUserId" ):
				key=words[0];
				value=words[1];
				dbUserIdValue=words[1].split("\n")[0];
			elif ( words[0]=="dbSchemaName" ):
				key=words[0];
				value=words[1];
				dbSchemaNameValue=words[1].split("\n")[0];
			elif ( words[0] in needPathConversionKeys):
				key=words[0];
				value=convertPathFrom60xTo61(words[1]);
			else:	
				key=words[0];
				value=words[1];
			#endIf
			
			destline=key+"="+value;
			trace(destline);
			destFile.writelines(destline);
		#endIf
	#endFor
	
	prodVersion = get3DigitProductVersion();
	
	#add some new properties of  wps/wesb 62x profile.
	if ( prodVersion == '6.1.0' or prodVersion == '6.1.2'):
		if (dbTypeValue.upper()=='ORACLE'):
			destFile.writelines("dbCommonUserId=dbUserIdValue\n");
	destFile.close();   
	trace("****************copyFile() end****************");
	return 1;
#endDef

#-----------------------------------------------------------------
# Apply for 602x Migration
# copy some required properties from a temp/wbiservber.property file  into a new commondb.property file 
#-----------------------------------------------------------------  
def copyFile(source,dest,profilePath):
	trace("****************copyFile() start****************");
	if( existsPath(source)==0 ):
		trace("migration failed because it cannot find the file "+source);
		return 0;
	#endIf

	sourceFile=open(source,"r");
	destFile=open(dest,"w");
	srclines=sourceFile.readlines();
	sourceFile.close();
	
	dbTypeValue="";
	dbNameValue="";
	dbUserIdValue="";
	dbSchemaNameValue="";
	
	for srcline in srclines :
		words=srcline.split("=");
		
		keys=["templatePath","cellName","nodeName","hostName","federateLater","dmgrHost","dmgrPort","portsFile"];
		keys.append("dbName");
		keys.append("dbType");
		keys.append("dbDriverType");
		keys.append("dbLocation");
		keys.append("dbUserId");
		keys.append("dbServerPort");
		keys.append("dbServerName");
		keys.append("dbHostName");
		keys.append("dbInstance");
		keys.append("dbJDBCClasspath");
		keys.append("dbCreateNew");
		keys.append("dbSchemaName");
		keys.append("dbStorageGroup");
		keys.append("dbConnectionLocation");
		keys.append("configureAppScheduler");
		keys.append("appSchedulerServer");
		
		
		#print keys;
		if (len(words)==2 and words[0] in keys): 
			# specify some keys which are converted from 60x env to 61 env.
			needPathConversionKeys=["templatePath","dbLocation","dbJDBCClasspath"];
			
			# different handlers against different keys.
			if ( words[0]=='dbType' ) :
				if (words[1].upper()=='CLOUDSCAPE\n'):
					key=words[0];
					value='DERBY_EMBEDDED\n';
				elif( words[1].upper()=='ORACLE10G\n' or words[1].upper()=='ORACLE9I\n' ):
					key=words[0];
					value='ORACLE\n';
				elif ( words[1].upper()=='MSSQLSERVER_EMBEDDED\n'):
					key=words[0];
					value='MSSQLSERVER_MICROSOFT\n';
				else:
					key=words[0];
					value=words[1];
				#endIf
				dbTypeValue=value.split("\n")[0];
			elif ( words[0]=="dbName" ):
				key=words[0];
				value=words[1];
				dbNameValue=words[1].split("\n")[0];
			elif ( words[0] in needPathConversionKeys):
				key=words[0];
				value=convertPathFrom60xTo61(words[1]);
			elif ( words[0]=="dbUserId" ):
				key=words[0];
				value=words[1];
				dbUserIdValue=words[1].split("\n")[0];
			elif ( words[0]=="dbSchemaName" ):
				key=words[0];
				value=words[1];
				dbSchemaNameValue=words[1].split("\n")[0];
			else:	
				key=words[0];
				value=words[1];
			#endIf
			
			destline=key+"="+value;
			trace(destline);
			destFile.writelines(destline);
		#endIf
	#endFor
	
	#add some new properties of  wps 61x profile.
	destFile.writelines("dbCommonForME=false\n");
	destFile.writelines("fileStoreForME=false\n");
	destFile.writelines("dbDelayConfig=true\n");
	destFile.writelines("dbAlreadyConfigured=false\n");
	destFile.writelines("dbOutputScriptDir="+profilePath+File.separator+"dbscripts"+"\n");
	
	#add some new properties of  wps/wesb 62x profile.
	if (dbTypeValue.upper()=='ORACLE'):
		destFile.writelines("dbCommonUserId=dbUserIdValue\n");
	destFile.close();   
	trace("****************copyFile() end****************");
	return 1;
#endDef

#-----------------------------------------------------------------
# get a value of commondb property  from commondb.properties 
#-----------------------------------------------------------------  
	
def getCommonDBProperty(source,key):
	trace("****************getCommonDBProperty() start****************");
	
	if( (existsPath(source)==0) or (existsPath(source)==0)):
		trace("migration failed because it cannot find the file "+source);
		return 0;
	#endIf

	sourceFile=open(source,"r");
	srclines=sourceFile.readlines();
	sourceFile.close();
	
	value="";
	for srcline in srclines :
		words=srcline.split("=");
		keys=["templatePath","cellName","nodeName","hostName","federateLater","dmgrHost","dmgrPort","portsFile"];
		keys.append("dbName");
		keys.append("dbType");
		keys.append("dbDriverType");
		keys.append("dbLocation");
		keys.append("dbUserId");
		keys.append("dbServerPort");
		keys.append("dbServerName");
		keys.append("dbHostName");
		keys.append("dbInstance");
		keys.append("dbJDBCClasspath");
		keys.append("dbCreateNew");
		keys.append("dbSchemaName");
		keys.append("dbStorageGroup");
		keys.append("dbConnectionLocation");
		keys.append("configureAppScheduler");
		keys.append("appSchedulerServer");	
		keys.append("dbCommonForME");
		keys.append("fileStoreForME");
		keys.append("dbDelayConfig");
		keys.append("dbOutputScriptDir");
		keys.append("dbAlreadyConfigured");
		keys.append("dbCommonUserId");		
		
		# trace("current property:"+words[0]);
		# trace("current property value:"+words[1]);
		if (len(words)==2 and words[0] in keys): 
			if ( words[0] == key ) :
				#trace("current property value:"+words[0]);
				value=words[1].split("\n")[0];
				break;
			else:
				value="";
			#endIf
		#endIf
	#endFor
	
	trace("****************getCommonDBProperty() end****************");
	return value;
#endDef

#--------------------------------------------------------------
# Check duplicate jndiName jdbc/WPSDB and delete it
#-------------------------------------------------------------
def removeDuplicateJndiNameOfCommonDB():
	trace("****************removeDuplicateJndiNameOfCommonDB() start****************");
	
	# get commondb datasource created by 61 and delete it.
	commonDBDataSourceName="WBI_DataSource";
	commonDBDataSourceId=queryDuplicateCommonDBDataSource(commonDBDataSourceName);
	
	global AdminConfig;
	if (commonDBDataSourceId != ""):
		AdminConfig.remove(commonDBDataSourceId);
		AdminConfig.save();
		trace(" Match Found and CommonDB DataSource is deleted. ");
	#endIf
	
	trace("****************removeDuplicateJndiNameOfCommonDB() end****************");
	return 1;
#endDef

#--------------------------------------------------------------
# query Datasource with  jndiName jdbc/WPSDB and given datasource name.
#-------------------------------------------------------------
def queryDuplicateCommonDBDataSource(DatasourceName):
	trace("****************queryDuplicateCommonDBDataSource() start****************");
	
	commonDBJNDIName="jdbc/WPSDB";
	commonDBDataSourceId="";
	
	global AdminConfig;
	dataSourceList=AdminConfig.list("DataSource")
	dataSources = wsadminToList(dataSourceList);
	for id in dataSources:
		curAttVal1=AdminConfig.showAttribute(id,"jndiName");
		#curAttVal11 = wsadminToList(curAttVal1);
		if(curAttVal1==commonDBJNDIName):
			curAttVal2=AdminConfig.showAttribute(id,"name");
			#curAttVal22=wsadminToList(curAttVal2);
			if(curAttVal2 == DatasourceName):
				trace("## jndiName:"+curAttVal1+"...DataSourceName:"+curAttVal2);
				commonDBDataSourceId=id;
				break;
				#endIf
			#endIf
		#endIf
	#endFor
	
	trace(" Match Found and CommonDB datasource Id: "+commonDBDataSourceId);
	trace("****************queryDuplicateCommonDBDataSource() end****************");
	return commonDBDataSourceId;
#endDef

#--------------------------------------------------------------
# query Common Datasource with  jndiName jdbc/WPSDB
#-------------------------------------------------------------
def queryCommonDBDataSource():
	trace("****************queryCommonDBDataSource() start****************");
	
	commonDBJNDIName="jdbc/WPSDB";
	commonDBDataSourceId="";
	
	global AdminConfig;
	dataSourceList=AdminConfig.list("DataSource")
	dataSources = wsadminToList(dataSourceList);
	for id in dataSources:
		curAttVal1=AdminConfig.showAttribute(id,"jndiName");
		#curAttVal11 = wsadminToList(curAttVal1);
		if(curAttVal1==commonDBJNDIName):
			commonDBDataSourceId=id;
			break;
		#endIf
	#endFor
	
	trace(" Match Found and CommonDB datasource Id: "+commonDBDataSourceId);	
	trace("****************queryCommonDBDataSource() end****************");
	return commonDBDataSourceId;
#endDef

#--------------------------------------------------------------
# query Datasource with  jndiName 
#-------------------------------------------------------------

def queryDataSource(jndiName):
	trace("****************queryCommonDBDataSource() start****************");
	
	commonDBJNDIName=jndiName;
	DataSourceId="";
	
	global AdminConfig;
	dataSourceList=AdminConfig.list("DataSource")
	dataSources = wsadminToList(dataSourceList);
	for id in dataSources:
		curAttVal1=AdminConfig.showAttribute(id,"jndiName");
		if(curAttVal1==commonDBJNDIName):
			DataSourceId=id;
			break;
		#endIf
	#endFor
	
	trace(" Match Found and CommonDB datasource Id: "+DataSourceId);	
	trace("****************queryDataSource() end****************");
	return DataSourceId;
#endDef

#-----------------------------------------------------------------
# Update  a attributes in JDBCProvider.
# For example:
#    <classpath> ,<nativepath>
#-----------------------------------------------------------------
def updateJDBCProviderAttribute(attributeName,attributeValue):
	trace("****************updateJDBCProviderAttribute() start****************");
	
	commonDBDataSourceId=queryCommonDBDataSource();
	
	global AdminConfig;
	if (commonDBDataSourceId!=""):
		CommonDBJDBCProviderId=AdminConfig.showAttribute(commonDBDataSourceId,"provider");
		originalAttributeValue=AdminConfig.showAttribute(CommonDBJDBCProviderId,attributeName);
		finalAttributeValue=attributeValue;
		
		trace("CommonDB JDBCProvider Id:"+CommonDBJDBCProviderId);
		trace("original attributeValue:"+originalAttributeValue);
		trace("new added attributeValue:"+attributeValue);	
		trace("final attributeValue:"+finalAttributeValue);
		
		attributes = [[attributeName,finalAttributeValue]];
		AdminConfig.modify(CommonDBJDBCProviderId, attributes );
		AdminConfig.save();
	#endIf
	
	trace("****************updateJDBCProviderAttribute() end****************");
	return 1;
#endif

#-----------------------------------------------------------------
# Update  a attributes in DataSource.
# For example:
#    <datasourceHelperClassname> ,<nativepath>
#-----------------------------------------------------------------

def updateDataSourceAttribute(attributeName,attributeValue):
	trace("****************updateDataSourceAttribute() start****************");
	
	commonDBDataSourceId=queryCommonDBDataSource();
	
	global AdminConfig;
	if (commonDBDataSourceId!=""):
		originalAttributeValue=AdminConfig.showAttribute(commonDBDataSourceId,attributeName);
		finalAttributeValue=attributeValue;
		trace("CommonDB DataSource Id:"+commonDBDataSourceId);
		trace("original attributeValue:"+originalAttributeValue);
		trace("new added attributeValue:"+attributeValue);
			
		attributes = [[attributeName,finalAttributeValue]];
		AdminConfig.modify(commonDBDataSourceId, attributes );
		AdminConfig.save();
	#endIf
	
	trace("****************updateDataSourceAttribute() end****************");
	return 1;
#endif

#-----------------------------------------------------------------
# Update  a J2EEresourceproperty  in DataSource.
# For example:
#    <databasename>, <jndiName>
#-----------------------------------------------------------------


def updateDataSourceProperties(jndiName, propName,propValue):
	trace("****************updateDataSourceProperties() start****************");
	
	commonDBDataSourceId=queryDataSource(jndiName);
	global AdminConfig;
	if (commonDBDataSourceId!=""):
		propSet = AdminConfig.showAttribute(commonDBDataSourceId,"propertySet")
		resoucepropertiesList = wsadminToList(AdminConfig.list("J2EEResourceProperty", propSet))
		for id in resoucepropertiesList:
			curPropName=AdminConfig.showAttribute(id,"name");
			if (curPropName==propName):
				properties = [["value", propValue]];
				trace("original propertyValue:"+AdminConfig.showAttribute(id,"value"));
				trace("updated propertyValue:"+propValue);	
				AdminConfig.modify(id, properties)
				AdminConfig.save()
	
	trace("****************updateDataSourceProperties() end****************");
	return 1;
#endif

#-----------------------------------------------------------------
# Query  a J2EEresourceproperty  in DataSource.
# For example:
#    <databasename>, <URL>
#-----------------------------------------------------------------

def queryDataSourceProperties(jndiName, propName):
	trace("****************queryDataSourceProperties() start****************");
	commonDBDataSourceId=queryDataSource(jndiName);
	global AdminConfig;
	if (commonDBDataSourceId!=""):
		propSet = AdminConfig.showAttribute(commonDBDataSourceId,"propertySet")
		resoucepropertiesList = wsadminToList(AdminConfig.list("J2EEResourceProperty", propSet))
		for id in resoucepropertiesList:
			curPropName=AdminConfig.showAttribute(id,"name");
			if (curPropName==propName):
				curPropValue=AdminConfig.showAttribute(id,"value");
				trace("Value for "+propName+" is "+curPropValue);
				break	
	
	trace("****************queryDataSourceProperties() end****************");
	return curPropValue;
#endif



#-----------------------------------------------------------------
# Create WAS variables using name and value
#-----------------------------------------------------------------
def createVariable(variableName,variableValue,cellName,nodeName,serverName):
	trace("****************createVariable() start****************");
	
	global AdminConfig;
	scopeId=getScopeId(cellName,nodeName,serverName);
	trace("scopeId:"+scopeId);
	
	mapList=wsadminToList(AdminConfig.list("VariableMap", scopeId));
	
	filteredMapList=[];
	for item in mapList:
		item=getExactScopeId(item,cellName,nodeName,serverName);
		trace("item:"+item);
		if ( not item==""):
			filteredMapList.append(item);
	#endFor
	
	map =filteredMapList[0];	
	trace("VariableMap id:"+map);
	trace("variableName:" + variableName + " variableValue:"+str(variableValue));
	
	# check if the variable exists in specified scope. 
	# 1. if exists, update the value of the variable
	# 2. if not exists, create  the variable.
	varMapIds = getVariableMapIds (variableName,cellName,nodeName,serverName);
	if(len(varMapIds) > 0):
		setVariableValue(variableName,variableValue,cellName,nodeName,serverName);
	elif (not len(map)==0):
		name = ["symbolicName", variableName];
		value = ["value", variableValue];
		attrs = [name, value];
		
		# create WAS variable.
		AdminConfig.create("VariableSubstitutionEntry", map, attrs );
		AdminConfig.save( );
	else:
		pass;
	#endIf
	
	trace("****************createVariable() end****************");
#endif

#-----------------------------------------------------------------
# Update datasource proeprties .. :
#-----------------------------------------------------------------

def updateDatasource(dbTypeValue):
	trace("****************updateDatasource() start****************");

	if(getNodeType() == 'managed'):
		return 1;
		
	if (checkWPS61()): 
		if ( dbTypeValue.upper() == 'DERBY_EMBEDDED' or  dbTypeValue.upper() == 'DERBY_NETWORKSERVER' ):
			trace("It is > WPS 602 migration, update Derby path for the databaseName..");
			Path = queryDataSourceProperties("jdbc/WPSDB", "databaseName");
			Path = Path.replace('\\',"/");
			dest = getProfilePath()+File.separator+"properties"+File.separator+"commondb.properties";
			dbNameValue=getCommonDBProperty(dest,"dbName");
			DerbyPath = getProfilePath()+File.separator+"databases"+File.separator+dbNameValue;
			DerbyPath = DerbyPath.replace('\\',"/");
			trace("DerbyPath's value:"+DerbyPath);
			updateDataSourceProperties("jdbc/WPSDB" , "databaseName" , DerbyPath);
		#endif
	#endif
	trace("****************updateDatasource() end  ****************");

#enddef

#-----------------------------------------------------------------
# deal with all commondb variables :
#-----------------------------------------------------------------
def handleWASVariables(dbTypeValue):
	trace("****************handleWASVariables() start****************");
	
	db2_Zos=0;
	db2=0;
	
	osType = java.lang.System.getProperty("os.name");
	
	dbType_jdbc_classpath="";
	jdbcProvider_classpath="";
	trace("##osType="+osType);
	
	if (osType == 'z/OS'):
		db2_Zos=1;
	else:
		db2_Zos=0;
	#endIf
	
	if ( dbTypeValue.upper() == 'DERBY_EMBEDDED' ):
		dbType_jdbc_classpath='DERBY_JDBC_DRIVER_PATH';
		jdbcProvider_classpath='${DERBY_JDBC_DRIVER_PATH}/derby.jar';
	elif ( dbTypeValue.upper() == 'DERBY_NETWORKSERVER' ):
		dbType_jdbc_classpath='DERBY_JDBC_DRIVER_PATH';
		jdbcProvider_classpath='${DERBY_JDBC_DRIVER_PATH}/derby.jar';
	elif ( dbTypeValue.upper() == 'DB2_UNIVERSAL' ):
		dbType_jdbc_classpath='DB2UNIVERSAL_JDBC_DRIVER_PATH';
		jdbcProvider_classpath='${DB2UNIVERSAL_JDBC_DRIVER_PATH}/db2jcc.jar;${UNIVERSAL_JDBC_DRIVER_PATH}/db2jcc_license_cu.jar;${DB2UNIVERSAL_JDBC_DRIVER_PATH}/db2jcc_license_cisuz.jar';
		db2=1;
	elif ( dbTypeValue.upper() == 'DB2UDBOS390_V8_1' ):
		dbType_jdbc_classpath='DB2UNIVERSAL_JDBC_DRIVER_PATH';
		jdbcProvider_classpath='${DB2UNIVERSAL_JDBC_DRIVER_PATH}/db2jcc.jar;${UNIVERSAL_JDBC_DRIVER_PATH}/db2jcc_license_cu.jar;${DB2UNIVERSAL_JDBC_DRIVER_PATH}/db2jcc_license_cisuz.jar';
		db2=1;
	elif ( dbTypeValue.upper() == 'DB2UDBOS390_V9_1' ):
		dbType_jdbc_classpath='DB2UNIVERSAL_JDBC_DRIVER_PATH';
		jdbcProvider_classpath='${DB2UNIVERSAL_JDBC_DRIVER_PATH}/db2jcc.jar;${UNIVERSAL_JDBC_DRIVER_PATH}/db2jcc_license_cu.jar;${DB2UNIVERSAL_JDBC_DRIVER_PATH}/db2jcc_license_cisuz.jar';
		db2=1;
	elif ( dbTypeValue.upper() == 'DB2UDBISERIES_TOOLBOX' ):
		dbType_jdbc_classpath='OS400_TOOLBOX_JDBC_DRIVER_PATH';
		jdbcProvider_classpath='${OS400_TOOLBOX_JDBC_DRIVER_PATH}/jt400.jar';
	elif ( dbTypeValue.upper() == 'DB2_CLI' ):
		dbType_jdbc_classpath='DB2_JDBC_DRIVER_PATH';
		jdbcProvider_classpath='${DB2_JDBC_DRIVER_PATH}/db2java.zip';
	elif ( dbTypeValue.upper() == 'INFORMIX' ):
		dbType_jdbc_classpath='INFORMIX_JDBC_DRIVER_PATH';
		jdbcProvider_classpath='${INFORMIX_JDBC_DRIVER_PATH}/ifxjdbc.jar;${INFORMIX_JDBC_DRIVER_PATH}/ifxjdbcx.jar';
	elif ( dbTypeValue.upper() == 'MSSQLSERVER_DATADIRECT' ):
		dbType_jdbc_classpath='CONNECTJDBC_JDBC_DRIVER_PATH';
		jdbcProvider_classpath='${CONNECTJDBC_JDBC_DRIVER_PATH}/sqlserver.jar;${CONNECTJDBC_JDBC_DRIVER_PATH}/base.jar;${CONNECTJDBC_JDBC_DRIVER_PATH}/util.jar;${CONNECTJDBC_JDBC_DRIVER_PATH}/../spy/spy.jar';
	elif ( dbTypeValue.upper() == 'MSSQLSERVER_MICROSOFT' ):
		dbType_jdbc_classpath='MICROSOFT_JDBC_DRIVER_PATH';
		jdbcProvider_classpath='${MICROSOFT_JDBC_DRIVER_PATH}/sqljdbc.jar';
		dataSource_helperClass='com.ibm.websphere.rsadapter.MicrosoftSQLServerDataStoreHelper';
	elif ( dbTypeValue.upper() == 'ORACLE' ):
		dbType_jdbc_classpath='ORACLE_JDBC_DRIVER_PATH';
		jdbcProvider_classpath='${ORACLE_JDBC_DRIVER_PATH}/ojdbc6.jar';
		dataSource_helperClass='com.ibm.websphere.rsadapter.Oracle11gDataStoreHelper';
	else:
		dbType_jdbc_classpath='';
		jdbcProvider_classpath='';
	#endIf
	
	#profile type judgment
	nodeType=getNodeType();
	profileLevel="";
	if ( nodeType == 'managed' or nodeType == 'unmanaged' ):
		# standalone profile and custom profile
		cellName=getCellName();
		nodeName=getNodeName();
		profileLevel="node";
	else:
		# dmgr profile
		cellName=getCellName();
		nodeName='';
		profileLevel="cell";
	#endIf
		
	serverName='';
	
	# get the value of "JDBC_DRIVER_PATH" variable.
	jdbcdriverpath=getVariableValue("JDBC_DRIVER_PATH",cellName,nodeName,serverName);
	trace("JDBC_DRIVER_PATH's value:"+jdbcdriverpath);
	
	# get the value of "${dbType}_JDBC_DRIVER_PATH" variable.
	if (not checkWPS61()):
		dbtypedriverpath=jdbcdriverpath;
		# Set Derby to correct absolutepath 
		if ( (dbTypeValue.upper() == 'DERBY_NETWORKSERVER' or dbTypeValue.upper() == 'DERBY_EMBEDDED' ) ):
			dbtypedriverpath=getWASHome()+File.separator+"derby"+File.separator+"lib";
	else:
		dbtypedriverpath=getVariableValue(dbType_jdbc_classpath,cellName,nodeName,serverName);
	#endIf
	
	# general settings 
	
	dbtypedriverpath=dbtypedriverpath.replace('\\',"/");
	dbtypedriverpath=convertPathFrom60xTo61(dbtypedriverpath);
	
	universaldriverpath="${WAS_INSTALL_ROOT}"+File.separator+"universalDriver"+File.separator+"lib";
	universaldriverpath=universaldriverpath.replace('\\',"/");
	universal_absolute_driverpath=getWASHome()+File.separator+"universalDriver"+File.separator+"lib";
	trace("UNIVERSAL_JDBC_DRIVER_PATH value:"+universaldriverpath);
	trace("universal_absolute_driverpath value:"+universal_absolute_driverpath);
	trace("${dbType}_JDBC_DRIVER_PATH's value:"+dbtypedriverpath);
	
	# 1.create <classpath> of CommonDB JDBCProvider related to dbType.
	if (not checkWPS61()):
		if ( nodeType != 'managed'):
			updateJDBCProviderAttribute("classpath",jdbcProvider_classpath);
		#endif
	else:
		# Update classpath for migrated oracle/sqlserver providers
		if ( (dbTypeValue.upper() == 'ORACLE' or dbTypeValue.upper() == 'MSSQLSERVER_MICROSOFT' ) and  ( nodeType != 'managed')): 
			updateJDBCProviderAttribute("classpath",jdbcProvider_classpath);
	#endif
	# 1.1 Update helperClass for migrated Oracle providers in v7
	if ( ( dbTypeValue.upper() == 'ORACLE' or  dbTypeValue.upper() == 'MSSQLSERVER_MICROSOFT' ) and  ( nodeType != 'managed')): 
		updateDataSourceAttribute("datasourceHelperClassname",dataSource_helperClass);
	
	
	# 2.create corresponding WAS variables ('${dbType}_JDBC_DRIVER_PATH') related  to dbType.
	oldHome = getMigratedWASHome();
	oldHome=oldHome.replace('\\',"/");
	was_path = getWASHome();
	was_path=was_path.replace('\\',"/");
	if ( dbType_jdbc_classpath.upper() == 'DERBY_JDBC_DRIVER_PATH' ):
		if ( dbtypedriverpath.upper().find(oldHome.upper()) == 0):
			dbtypedriverpath="${WAS_INSTALL_ROOT}"+File.separator+"derby"+File.separator+"lib";
			dbtypedriverpath=dbtypedriverpath.replace('\\',"/");
			createVariable(dbType_jdbc_classpath,dbtypedriverpath,cellName,nodeName,serverName);
			# Create WAS_INSTALL_ROOT variable at cell level 
			if (profileLevel=="cell"):
				createVariable('WAS_INSTALL_ROOT',was_path,cellName,nodeName,serverName);
		else:
			# create variable anyway , needed when oldProfile is from <wps61
			createVariable(dbType_jdbc_classpath,dbtypedriverpath,cellName,nodeName,serverName);
		#endif
	elif ( dbType_jdbc_classpath.upper() == 'DB2UNIVERSAL_JDBC_DRIVER_PATH' ):
		if ( dbtypedriverpath.find("${WAS_INSTALL_ROOT}") != 0): 
			# if  WAS_INSTALL_ROOT does not exist in the path
			if ( dbtypedriverpath.upper().find(oldHome.upper()) == 0):
				# if  driver path has old profile's  WAS_INSTALL_ROOT 
				dbtypedriverpath="${WAS_INSTALL_ROOT}"+File.separator+"universalDriver_wbi"+File.separator+"lib";
				dbtypedriverpath=dbtypedriverpath.replace('\\',"/");
				createVariable(dbType_jdbc_classpath,dbtypedriverpath,cellName,nodeName,serverName);
				# Create WAS_INSTALL_ROOT variable at cell level 
				if (profileLevel=="cell"):
					createVariable('WAS_INSTALL_ROOT',was_path,cellName,nodeName,serverName);
				createVariable('UNIVERSAL_JDBC_DRIVER_PATH',universaldriverpath,cellName,nodeName,serverName);
			else:
				# driver path  different than was_install_root
				createVariable(dbType_jdbc_classpath,dbtypedriverpath,cellName,nodeName,serverName);
				if (profileLevel=="cell"):
					createVariable('WAS_INSTALL_ROOT',was_path,cellName,nodeName,serverName);
				createVariable('UNIVERSAL_JDBC_DRIVER_PATH',universaldriverpath,cellName,nodeName,serverName);
			#endif
		else:
			# create variable anyway,needed when oldProfile is from <wps61  and WAS_INSTALL_ROOT does exist
			createVariable(dbType_jdbc_classpath,dbtypedriverpath,cellName,nodeName,serverName);
			if (profileLevel=="cell"):
					createVariable('WAS_INSTALL_ROOT',was_path,cellName,nodeName,serverName);
			createVariable('UNIVERSAL_JDBC_DRIVER_PATH',universaldriverpath,cellName,nodeName,serverName);
		#endif	
	else:
		createVariable(dbType_jdbc_classpath,dbtypedriverpath,cellName,nodeName,serverName);
	#endif
	
	# 3.create special WAS variables and <classpath> of CommonDB JDBCProvider.
	
	if (db2 == 1 and db2_Zos == 0):
		WasVariable='DB2UNIVERSAL_JDBC_DRIVER_NATIVEPATH';
		if ( nodeType != 'managed'):
			updateJDBCProviderAttribute("nativepath","${DB2UNIVERSAL_JDBC_DRIVER_NATIVEPATH}");
		#endif
		createVariable(WasVariable,"",cellName,nodeName,serverName);
	elif(db2 == 1 and db2_Zos == 1):
		WasVariable='DB2UNIVERSAL_JDBC_DRIVER_NATIVEPATH';
		zOsVariable = dbtypedriverpath+File.separator+".."+File.separator+"lib";
		if ( nodeType != 'managed'):
			updateJDBCProviderAttribute("nativepath","${DB2UNIVERSAL_JDBC_DRIVER_NATIVEPATH}");
		#endif
		createVariable(WasVariable,zOsVariable,cellName,nodeName,serverName);
	#endIf
	
	# 4.if profile is dmgr profile ,then it has to update the following variables:
	# '${dbType}_JDBC_DRIVER_PATH' , 'DB2UNIVERSAL_JDBC_DRIVER_NATIVEPATH' and 'UNIVERSAL_JDBC_DRIVER_PATH' on node level.
	if (profileLevel=="cell"):
		nodeName=getNodeName();
		
		# create '${dbType}_JDBC_DRIVER_PATH'
		createVariable(dbType_jdbc_classpath,dbtypedriverpath,cellName,nodeName,serverName);
		
		# create 'UNIVERSAL_JDBC_DRIVER_PATH'
		if (db2 == 1):
			WasVariable='UNIVERSAL_JDBC_DRIVER_PATH';
			createVariable(WasVariable,universaldriverpath,cellName,nodeName,serverName);
		#endIf
		
		# create 'DB2UNIVERSAL_JDBC_DRIVER_NATIVEPATH'
		if (db2 == 1 and db2_Zos == 0):
			WasVariable='DB2UNIVERSAL_JDBC_DRIVER_NATIVEPATH';
			createVariable(WasVariable,"",cellName,nodeName,serverName);
		elif(db2 == 1 and db2_Zos == 1):
			WasVariable='DB2UNIVERSAL_JDBC_DRIVER_NATIVEPATH';
			zOsVariable = dbtypedriverpath+File.separator+".."+File.separator+"lib"
			createVariable(WasVariable,zOsVariable,cellName,nodeName,serverName);
		#endIf
	#endIf
	
	# 5.Update corresponding WAS variables ('JDBC_DRIVER_PATH') related  to dbType.
	# WasVariable='JDBC_DRIVER_PATH';
	# createVariable(WasVariable,dbtypedriverpath,cellName,nodeName,serverName);
	
	trace("****************handleWASVariables() end****************");
#endDef

#-----------------------------------------------------------------
# copy all db script files in 60x to 61  :
#-----------------------------------------------------------------
def copyDbTypeScriptFiles(dest):
	profilePath=getProfilePath();
	dbTypeValue=getCommonDBProperty(dest,"dbType");
	dbNameValue=getCommonDBProperty(dest,"dbName");
	previousWASHome=getMigratedWASHome();
	previousProfileName=getPreviousProfileName();
	dbTypeScriptDirName=getDbTypeScriptDir(dbTypeValue);
	
	trace("dbTypeValue:"+dbTypeValue);
	trace("dbNameValue:"+dbNameValue);
	trace("previousWASHome:"+previousWASHome);
	trace("previousProfileName:"+previousProfileName);
	trace("dbTypeScriptDirName:"+dbTypeScriptDirName);
	
	sourceFolder=previousWASHome+File.separator+"profiles"+File.separator+previousProfileName+File.separator+"databases"+File.separator+dbNameValue;
	destFolder=profilePath+File.separator+"dbscripts"+File.separator+"CommonDB"+File.separator+dbTypeScriptDirName+File.separator+dbNameValue;
	trace("sourceFolder:"+sourceFolder+" destFolder:"+destFolder);
	if (not os.path.exists(destFolder)):
		try:
			os.makedirs(destFolder);
		except:
			pass;
		#endTry
	#endIf
	
	shutil.copytree(sourceFolder, destFolder);
#endDef

#-----------------------------------------------------------------
# get directory name according to dbType :
#-----------------------------------------------------------------
def getDbTypeScriptDir(dbTypeValue):
	trace("****************getDbTypeScriptDir() start****************");
	
	dbTypeScriptDir="";	
	if ( dbTypeValue.upper() == 'DERBY_EMBEDDED' ):
		dbTypeScriptDir='Derby';
	elif ( dbTypeValue.upper() == 'DERBY_NETWORKSERVER' ):
		dbTypeScriptDir='Derby';
	elif ( dbTypeValue.upper() == 'DB2_UNIVERSAL' ):
		dbTypeScriptDir='DB2';
	elif ( dbTypeValue.upper() == 'DB2UDBOS390_V7_1' ):
		dbTypeScriptDir='DB2zOSV7';
	elif ( dbTypeValue.upper() == 'DB2UDBOS390_V8_1' ):
		dbTypeScriptDir='DB2zOSV8';
	elif ( dbTypeValue.upper() == 'DB2UDBOS390_V9_1' ):
		dbTypeScriptDir='DB2zOSV9';
	elif ( dbTypeValue.upper() == 'DB2UDBISERIES_NATIVE' ):
		dbTypeScriptDir='DB2iSeries';
	elif ( dbTypeValue.upper() == 'DB2UDBISERIES_TOOLBOX' ):
		dbTypeScriptDir='DB2iSeries';
	elif ( dbTypeValue.upper() == 'DB2_CLI' ):
		dbTypeScriptDir='DB2';
	elif ( dbTypeValue.upper() == 'INFORMIX' ):
		dbTypeScriptDir='Informix';
	elif ( dbTypeValue.upper() == 'MSSQLSERVER_MICROSOFT' ):
		dbTypeScriptDir='SQLServer';
	elif ( dbTypeValue.upper() == 'MSSQLSERVER_DATADIRECT' ):
		dbTypeScriptDir='SQLServer';
	elif ( dbTypeValue.upper() == 'ORACLE9I' ):
		dbTypeScriptDir='Oracle';
	elif ( dbTypeValue.upper() == 'ORACLE10G' ):
		dbTypeScriptDir='Oracle';
	elif ( dbTypeValue.upper() == 'ORACLE' ):
		dbTypeScriptDir='Oracle';
	else:
		dbTypeScriptDir='Oracle';
	#endIf
	
	trace("****************getDbTypeScriptDir() end****************");
	return dbTypeScriptDir;
#endDef
#--------------------------------------------------------------------------
#  Check to see type of profile that get migrating to WPS Latest...
#--------------------------------------------------------------------------
def isBPCProfile(profilechecker):
	readFile=open(profilechecker,"r");
	readlines=readFile.readlines();
	readFile.close();
	wbiserver=0;
	bpcserver=0;
	
	for srcline in readlines :
		words=srcline.split("=");
		if ( words[0] == 'augmentor.wbiserver'):
			value=words[1].split("\n")[0];
			if ( value == 'true'): 
				wbiserver=1;
			else:
				wbiserver=0;
			#endif
		elif ( words[0] == 'augmentor.bfm'):
			value=words[1].split("\n")[0];
			if ( value == 'true'): 
				bpcserver=1;
			else:
				bpcserver=0;
			#endif
		#endif
	#endfor
	if (  bpcserver == 1 and wbiserver == 0 ):
		return "true";
#endDef

#------------------------------------------------------------------------------
# check whether migrating profile is >= 6.1
# if true return 1, false return 0
# This is needed to read commondb.properties otherwise wbiserver.properties .
#------------------------------------------------------------------------------

def checkWPS61():
	print "inside checkWPS61"
	result = 0
	nodeVersion = getPropertyValue('wbi.upgrade.previous.version')
	
	print "nodeVersion is: " + str(nodeVersion)
	nodeVer = nodeVersion[0:3]
	print "nodeVer is: " + nodeVer
	
	if (nodeVer >= "6.1"):
		# This means any 6.1.x and above  will be upgraded
		result = 1
	else :
		# This means 6.0.2.x will be upgraded
		result = 0
		
	return result
# endDef

#------------------------------------------------------------------------------
# Get 3 digit migrated product version
#------------------------------------------------------------------------------

def get3DigitProductVersion():
	print "inside get3DigitProductVersion"
	result = 0
	productVersion = getPropertyValue('wbi.upgrade.previous.version')
	result = productVersion[0:5]
	print "productVersion is: " + str(result)
	return result
# endDef


#-----------------------------------------------------------------
# Main program:
#-----------------------------------------------------------------
def main():

	profileType = getPropertyValue('wbi.upgrade.profile.type')
	if (profileType != 'ESB' and profileType != 'WPS' and profileType != 'WSFabric'):
		print 'It is non WPS, ESB and WSFabric profile migration. Skipping CommonDB updates....'
		return 0
	previousVersion = getPropertyValue('wbi.upgrade.previous.version')
	if (profileType == 'ESB' and previousVersion[0:5] <= '6.0.2' ):
		print 'It is an ESB 602 or older profile migration. Skipping CommonDB updates....'
		return 0
	
	profilePath=getProfilePath();
	
	profilechecker=profilePath+File.separator+"temp"+File.separator+"bpm_migration.properties";
	trace("Read properties from "+profilechecker);
	
	trace("The CommonDB Component Post Migration continues..");

	source=profilePath+File.separator+"temp"+File.separator+"wbiserver.properties";
	trace("Read properties from "+source);

	dest=profilePath+File.separator+"properties"+File.separator+"commondb.properties";
	trace("Copy properties into a new file "+dest);

	# if success, it is 1, otherwise, it is 0.
	flag_success=1;
	failureReason="";
	
	# 1.copy all useful stuff into commondb.properties from temp/wbiserver.properties or temp/commondb.properties
	if (not checkWPS61()):
		if (copyFile(source,dest,profilePath) == 0):
			failureReason="copyFile operation failure.";
			flag_success=0;
		#endIf
	else:
		source=profilePath+File.separator+"temp"+File.separator+"commondb.properties";
		trace("read properties from "+source);
		if (copyFileFrom61x(source,dest,profilePath) == 0):
			failureReason="copyFile operation failure.";
			flag_success=0;
		#endIf
	#endIf
	
	#2. copy all db script files in 60x profile to 61 profiles
	#copyDbTypeScriptFiles(dest);
	

	
	dbTypeValue=getCommonDBProperty(dest,"dbType");
	
	# 4.deal with all was variables related to commondb.
	if (handleWASVariables(dbTypeValue) == 0):
		failureReason="all commondb variables operation failure.";
		flag_success=0;
	#endIf
	
	# 5.Set Datasource properties if needed.
	if (updateDatasource(dbTypeValue) == 0):
		failureReason="updating datasource property operation failure.";
		flag_success=0;
	#endIf
	
	if (flag_success == 0):
		trace("CommonDB Migration failed due to " + failureReason);
	else:
		trace("CommonDB Migration is Successful !");
	#endIf
#endDef



#-----------------------------------------------------------------
# Start Main function
#-----------------------------------------------------------------
main();
#-----------------------------------------------------------------
# End Main function
#-----------------------------------------------------------------